Module aabb

Module aabb 

Functions

enlarge_aabb
Enlarge a to contain b. (b3EnlargeAABB)
farthest_point_on_aabb
Return the AABB corner farthest from p along each axis independently. (b3FarthestPointOnAABB)
perimeter
Get the surface area of an AABB. (b3Perimeter)
ray_cast_aabb
Ray cast an AABB. This is a custom function used by height fields. (b3RayCastAABB)