Body

Struct Body 

pub struct Body {
Show 23 fields pub user_data: u64, pub set_index: i32, pub local_index: i32, pub head_contact_key: i32, pub contact_count: i32, pub head_shape_id: i32, pub shape_count: i32, pub head_chain_id: i32, pub head_joint_key: i32, pub joint_count: i32, pub island_id: i32, pub island_index: i32, pub sleep_threshold: f32, pub sleep_time: f32, pub sleep_velocity: f32, pub mass: f32, pub inertia: Matrix3, pub body_move_index: i32, pub id: i32, pub flags: u32, pub name_id: u32, pub type_: BodyType, pub generation: u16,
}
Body organizational details that are not used in the solver. (b3Body)

Fields

user_data: u64set_index: i32

Index of solver set stored in World. May be NULL_INDEX.

local_index: i32

Body sim and state index within set. May be NULL_INDEX.

head_contact_key: i32

[31 : contactId | 1 : edgeIndex]

contact_count: i32head_shape_id: i32shape_count: i32head_chain_id: i32head_joint_key: i32

[31 : jointId | 1 : edgeIndex]

joint_count: i32island_id: i32

All enabled dynamic and kinematic bodies are in an island.

island_index: i32

Index into the island’s bodies array for O(1) swap-removal. NULL_INDEX when not in an island.

sleep_threshold: f32sleep_time: f32sleep_velocity: f32mass: f32inertia: Matrix3

Local space inertia

body_move_index: i32

Adjusts the fellAsleep flag in the body move array

id: i32flags: u32

body_flags bits

name_id: u32type_: BodyTypegeneration: u16

Monotonically advanced when a body is allocated in this slot. Used to check for invalid BodyId.