pub struct BodySim {Show 18 fields
pub transform: WorldTransform,
pub center: Pos,
pub rotation0: Quat,
pub center0: Pos,
pub local_center: Vec3,
pub force: Vec3,
pub torque: Vec3,
pub inv_mass: f32,
pub inv_inertia_local: Matrix3,
pub inv_inertia_world: Matrix3,
pub min_extent: f32,
pub max_extent: Vec3,
pub max_angular_velocity: f32,
pub linear_damping: f32,
pub angular_damping: f32,
pub gravity_scale: f32,
pub body_id: i32,
pub flags: u32,
}Expand description
Body simulation data used for integration of position and velocity. Transform data used for collision and solver preparation. (b3BodySim)
Fields
transform: WorldTransformTransform for body origin (double translation in large world mode)
center: PosCenter of mass position in world space
rotation0: QuatPrevious rotation and COM for TOI
center0: Poslocal_center: Vec3Location of center of mass relative to the body origin
force: Vec3torque: Vec3inv_mass: f32inv_inertia_local: Matrix3Rotational inertia about the center of mass. World inverse inertia must be updated whenever the body rotation is modified.
inv_inertia_world: Matrix3min_extent: f32max_extent: Vec3max_angular_velocity: f32linear_damping: f32angular_damping: f32gravity_scale: f32body_id: i32Index of Body
flags: u32body_flags bits