pub struct BodyState {
pub linear_velocity: Vec3,
pub angular_velocity: Vec3,
pub delta_position: Vec3,
pub delta_rotation: Quat,
pub flags: u32,
}Expand description
Body state designed for fast conversion to and from SIMD via scatter-gather. Only awake dynamic and kinematic bodies have a body state. Used in the performance critical constraint solver. (b3BodyState, 56 bytes)
Fields
linear_velocity: Vec3angular_velocity: Vec3delta_position: Vec3Using delta position reduces round-off error far from the origin
delta_rotation: QuatDelta rotation; identity for static bodies via a dummy state
flags: u32body_flags bits — important: locking, dynamic