Module broad_phase

Module broad_phase 

Structs

BroadPhase
The broad-phase is used for computing pairs and performing volume queries and ray casts. It does not persist pairs; it reports potentially new pairs. (b3BroadPhase)

Functions

proxy_id
(B3_PROXY_ID)
proxy_key
(B3_PROXY_KEY)
proxy_type
Store the proxy type in the lower 2 bits of the proxy key. (B3_PROXY_TYPE)
update_broad_phase_pairs
Find new proxy pairs and create contacts in deterministic move-array order. (b3UpdateBroadPhasePairs — serial)