pub fn convert_compound_to_bytes(compound: &CompoundData) -> Vec<u8> ⓘExpand description
Scrub and return the compound as a byte buffer. (b3ConvertCompoundToBytes)
pub fn convert_compound_to_bytes(compound: &CompoundData) -> Vec<u8> ⓘScrub and return the compound as a byte buffer. (b3ConvertCompoundToBytes)