pub fn overlap_compound(
shape: &CompoundData,
shape_transform: Transform,
proxy: &ShapeProxy,
) -> boolExpand description
Test overlap between a compound and a shape proxy. (b3OverlapCompound)
pub fn overlap_compound(
shape: &CompoundData,
shape_transform: Transform,
proxy: &ShapeProxy,
) -> boolTest overlap between a compound and a shape proxy. (b3OverlapCompound)