Module constants

Module constants 

Constants

AABB_MARGIN_FRACTION
Fraction of shape size used for the AABB movement margin. (B3_AABB_MARGIN_FRACTION)
BODY_NAME_LENGTH
Max body name length excluding null terminator. (B3_BODY_NAME_LENGTH)
CHILD_MASK
Mask for a child index packed into a pair key. (B3_CHILD_MASK)
CHILD_POWER
Bit width reserved for a child index in the pair key. (B3_CHILD_POWER)
CONTACT_MANIFOLD_COUNT_BUCKETS
Contact-point buckets for reporting manifold counts per pair. (B3_CONTACT_MANIFOLD_COUNT_BUCKETS)
CONTACT_RECYCLE_ANGULAR_DISTANCE
Angular distance threshold for contact recycling (cos² of half-angle). (B3_CONTACT_RECYCLE_ANGULAR_DISTANCE)
GRAPH_COLOR_COUNT
Maximum number of colors in the constraint graph. Constraints that cannot find a color are added to the overflow set. (B3_GRAPH_COLOR_COUNT)
MAX_CHILD_SHAPES
Maximum number of child shapes. (B3_MAX_CHILD_SHAPES)
MAX_MANIFOLD_POINTS
The maximum number of contact points between two touching shapes. (B3_MAX_MANIFOLD_POINTS)
MAX_MESH_CONTACT_TRIANGLES
Max triangles queried for one mesh contact. (B3_MAX_MESH_CONTACT_TRIANGLES)
MAX_POINTS_PER_TRIANGLE
Max clip points written per triangle during mesh narrow phase. (B3_MAX_POINTS_PER_TRIANGLE)
MAX_ROTATION
Maximum body rotation per time step to prevent numerical issues. (B3_MAX_ROTATION)
MAX_SHAPES
Maximum number of shapes. (B3_MAX_SHAPES)
MAX_SHAPE_CAST_POINTS
The maximum number of points to use for shape cast proxies (swept point cloud). (B3_MAX_SHAPE_CAST_POINTS)
MAX_WORKERS
Maximum parallel workers. Used for fixed-size arrays and worker-count clamping. The serial port still stores and clamps to this limit. (B3_MAX_WORKERS)
NULL_NAME
Null name id in the name cache. (B3_NULL_NAME)
RELAX_ITERATIONS
Relaxation iterations per sub-step (bias off). (solver.c: RELAX_ITERATIONS)
SHAPE_MASK
Mask for a shape index packed into a pair key. (B3_SHAPE_MASK)
SHAPE_NAME_LENGTH
Max shape name length excluding null terminator. (B3_SHAPE_NAME_LENGTH)
SHAPE_POWER
Bit width reserved for a shape index in crate::table::shape_pair_key. (B3_SHAPE_POWER)
SOLVER_ITERATIONS
Velocity constraint iterations per sub-step. (solver.c: ITERATIONS)
TIME_TO_SLEEP
Time a body must be still before it will go to sleep, in seconds. (B3_TIME_TO_SLEEP)

Functions

contact_recycle_distance
Default contact recycling distance. (B3_CONTACT_RECYCLE_DISTANCE)
huge
See huge.
linear_slop
A small length used as a collision and constraint tolerance. Usually it is chosen to be numerically significant, but visually insignificant. In meters. @warning modifying this can have a significant impact on stability (B3_LINEAR_SLOP)
max_aabb_margin
Maximum AABB margin used when expanding bounds for casts. (B3_MAX_AABB_MARGIN)
mesh_rest_offset
Rest offset for mesh contact to reduce ghost collisions. Must be at least linear_slop and less than speculative_distance. (B3_MESH_REST_OFFSET)
min_capsule_length
Minimum capsule segment length. (B3_MIN_CAPSULE_LENGTH)
overlap_slop
Used to determine if two shapes are overlapping. Typically about 10% of linear_slop. (B3_OVERLAP_SLOP)
speculative_distance
Used to determine if two shapes are overlapping. Typically about 4× linear_slop. (B3_SPECULATIVE_DISTANCE)