pub struct ContactEdge {
pub body_id: i32,
pub prev_key: i32,
pub next_key: i32,
}Expand description
A contact edge connects bodies and contacts in a contact graph where each body is a node and each contact is an edge. (b3ContactEdge)
Fields
body_id: i32prev_key: i32next_key: i32Trait Implementations
Sourceimpl Clone for ContactEdge
impl Clone for ContactEdge
Sourcefn clone(&self) -> ContactEdge
fn clone(&self) -> ContactEdge
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ContactEdge
Sourceimpl Debug for ContactEdge
impl Debug for ContactEdge
Sourceimpl Default for ContactEdge
impl Default for ContactEdge
impl Eq for ContactEdge
Sourceimpl PartialEq for ContactEdge
impl PartialEq for ContactEdge
impl StructuralPartialEq for ContactEdge