pub fn make_local_proxy(proxy: &ShapeProxy, transform: Transform) -> ShapeProxyExpand description
Transform a proxy into the local frame of transform.
(shape.c: b3MakeLocalProxy)
pub fn make_local_proxy(proxy: &ShapeProxy, transform: Transform) -> ShapeProxyTransform a proxy into the local frame of transform.
(shape.c: b3MakeLocalProxy)