pub fn make_proxy(points: &[Vec3], radius: f32) -> ShapeProxyExpand description
Make a proxy for use in overlap, shape cast, and related functions. This is
a deep copy of the points. (box2d-style helper; C uses a pointer in
b3ShapeProxy)
pub fn make_proxy(points: &[Vec3], radius: f32) -> ShapeProxyMake a proxy for use in overlap, shape cast, and related functions. This is
a deep copy of the points. (box2d-style helper; C uses a pointer in
b3ShapeProxy)