shape_cast

Function shape_cast 

pub fn shape_cast(input: &ShapeCastPairInput) -> CastOutput
Perform a linear shape cast of shape B moving and shape A fixed. Determines the hit point, normal, and translation fraction. The query runs in frame A, so the hit point and normal are returned in frame A. Initially touching shapes are a miss unless can_encroach allows it. (b3ShapeCast)

Shape cast using conservative advancement.