pub struct SimplexCache {
pub metric: f32,
pub count: u16,
pub index_a: [u8; 4],
pub index_b: [u8; 4],
}Expand description
Used to warm start the GJK simplex. If you call this function multiple times with nearby transforms this might improve performance. Otherwise you can zero initialize this. The distance cache must be initialized to zero on the first call. (b3SimplexCache)
Fields
metric: f32Value used to compare length, area, volume of two simplexes.
count: u16The number of stored simplex points
index_a: [u8; 4]The cached simplex indices on shape A
index_b: [u8; 4]The cached simplex indices on shape B