Sweep

Struct Sweep 

pub struct Sweep {
    pub local_center: Vec3,
    pub c1: Vec3,
    pub c2: Vec3,
    pub q1: Quat,
    pub q2: Quat,
}
This describes the motion of a body/shape for TOI computation. Shapes are defined with respect to the body origin, which may not coincide with the center of mass. However, to support dynamics we must interpolate the center of mass position. (b3Sweep)

Fields

local_center: Vec3

Local center of mass position

c1: Vec3

Starting center of mass world position

c2: Vec3

Ending center of mass world position

q1: Quat

Starting world rotation

q2: Quat

Ending world rotation