pub struct ToiOutput {
pub state: ToiState,
pub point: Vec3,
pub normal: Vec3,
pub fraction: f32,
pub distance: f32,
pub distance_iterations: i32,
pub push_back_iterations: i32,
pub root_iterations: i32,
pub used_fallback: bool,
}Expand description
Time of impact output. (b3TOIOutput)
Fields
state: ToiStateThe type of result
point: Vec3The hit point
normal: Vec3The hit normal
fraction: f32The sweep time of the collision
distance: f32The final distance
distance_iterations: i32Number of outer iterations
push_back_iterations: i32Total number of push back iterations
root_iterations: i32Total number of root iterations
used_fallback: boolIndicates that the time of impact detected initial overlap and used a
fallback sphere as a last ditch effort to prevent tunneling.
(Present in the C type; never set by b3TimeOfImpact in the pinned source.)