Module events

Module events 

Structs

BodyMoveEvent
Body move event, triggered when a body moves due to simulation. Not reported for bodies moved by the user. (b3BodyMoveEvent)
ContactBeginTouchEvent
A begin-touch event is generated when two shapes begin touching. (b3ContactBeginTouchEvent)
ContactData
The contact data for solid shape pairs. Manifolds are an owned snapshot of the contact’s current manifolds (C exposes a transient pointer). (b3ContactData)
ContactEndTouchEvent
An end touch event is generated when two shapes stop touching. (b3ContactEndTouchEvent)
ContactEvents
Contact events buffered in the world after a time step. (b3ContactEvents)
ContactHitEvent
A hit touch event is generated when two shapes collide faster than the hit speed threshold. (b3ContactHitEvent)
JointEvent
Joint event, reported for awake joints whose force and/or torque exceed the threshold. (b3JointEvent)
SensorBeginTouchEvent
A begin-touch event is generated when a shape starts to overlap a sensor shape. (b3SensorBeginTouchEvent)
SensorEndTouchEvent
An end touch event is generated when a shape stops overlapping a sensor shape. Always confirm the shape id is valid before use. (b3SensorEndTouchEvent)
SensorEvents
Sensor events buffered in the world for the current time step. Borrowed from world storage; invalidated by the next World::step. (b3SensorEvents)