pub struct ContactHitEvent {
pub shape_id_a: ShapeId,
pub shape_id_b: ShapeId,
pub contact_id: ContactId,
pub point: Pos,
pub normal: Vec3,
pub approach_speed: f32,
pub user_material_id_a: u64,
pub user_material_id_b: u64,
}Expand description
A hit touch event is generated when two shapes collide faster than the hit speed threshold. (b3ContactHitEvent)
Fields
shape_id_a: ShapeIdId of the first shape
shape_id_b: ShapeIdId of the second shape
contact_id: ContactIdId of the contact. @warning may have been destroyed
point: PosPoint where the shapes hit, a mid-point between the two surfaces.
normal: Vec3Normal vector pointing from shape A to shape B
approach_speed: f32The speed the shapes are approaching. Always positive.
user_material_id_a: u64User material on shape A
user_material_id_b: u64User material on shape B