pub fn overlap_capsule(
shape: &Capsule,
shape_transform: Transform,
proxy: &ShapeProxy,
) -> boolExpand description
Test overlap between a capsule and a shape proxy. (b3OverlapCapsule)
pub fn overlap_capsule(
shape: &Capsule,
shape_transform: Transform,
proxy: &ShapeProxy,
) -> boolTest overlap between a capsule and a shape proxy. (b3OverlapCapsule)