pub struct MassData {
pub mass: f32,
pub center: Vec3,
pub inertia: Matrix3,
}Expand description
This holds the mass data computed for a shape. (b3MassData)
Fields
mass: f32The shape mass
center: Vec3The local center of mass position.
inertia: Matrix3The inertia tensor about the shape center of mass.