pub struct ShapeCastInput {
pub proxy: ShapeProxy,
pub translation: Vec3,
pub max_fraction: f32,
pub can_encroach: bool,
}Expand description
Low level shape cast input in generic form. This allows casting an arbitrary point cloud wrapped with a radius. For example, a sphere is a single point with a non-zero radius. A capsule is two points with a non-zero radius. A box is eight points with a zero radius. (b3ShapeCastInput)
Fields
proxy: ShapeProxyA generic query shape.
translation: Vec3The translation of the shape cast.
max_fraction: f32The maximum fraction of the translation to consider, typically 1.
can_encroach: boolAllow shape cast to encroach when initially touching. This only works if the radius is greater than zero.