pub struct LocalManifoldPoint {
pub point: Vec3,
pub separation: f32,
pub pair: FeaturePair,
pub triangle_index: i32,
}Expand description
A local manifold point and normal in frame A. (b3LocalManifoldPoint)
Fields
point: Vec3Local point in frame A.
separation: f32The contact point separation. Negative for overlap.
pair: FeaturePairThe feature pair for this point.
triangle_index: i32The triangle index when collide with a mesh or height-field.