pub struct Manifold {
pub points: [ManifoldPoint; 4],
pub normal: Vec3,
pub twist_impulse: f32,
pub friction_impulse: Vec3,
pub rolling_impulse: Vec3,
pub point_count: i32,
}Expand description
A contact manifold describes the contact points between colliding shapes. (b3Manifold)
Fields
points: [ManifoldPoint; 4]The manifold points. There may be 0 to MAX_MANIFOLD_POINTS valid points.
normal: Vec3Unit normal in world space, points from shape A to shape B.
twist_impulse: f32Central friction angular impulse (applied about the normal).
friction_impulse: Vec3Central friction linear impulse.
rolling_impulse: Vec3Rolling resistance angular impulse.
point_count: i32The number of contact points, 0 to 4.