pub struct ManifoldPoint {
pub anchor_a: Vec3,
pub anchor_b: Vec3,
pub separation: f32,
pub base_separation: f32,
pub normal_impulse: f32,
pub total_normal_impulse: f32,
pub normal_velocity: f32,
pub feature_id: u32,
pub triangle_index: i32,
pub persisted: bool,
}Expand description
A manifold point is a contact point belonging to a contact manifold. Box3D uses speculative collision so some contact points may be separated. (b3ManifoldPoint)
Fields
anchor_a: Vec3Location of the contact point relative to body A center of mass in world space.
anchor_b: Vec3Location of the contact point relative to body B center of mass in world space.
separation: f32Separation of the contact point; negative if penetrating.
base_separation: f32Cached separation used for contact recycling.
normal_impulse: f32Impulse along the manifold normal from the final sub-step.
total_normal_impulse: f32Total normal impulse applied during sub-stepping.
normal_velocity: f32Relative normal velocity pre-solve. Negative means approaching.
feature_id: u32Uniquely identifies a contact point between two shapes.
triangle_index: i32Triangle index if one of the shapes is a mesh or height field.
persisted: boolDid this contact point exist in the previous step?