aabb_transform

Function aabb_transform 

pub fn aabb_transform(transform: Transform, a: Aabb) -> Aabb
Transform an axis-aligned bounding box. This can create a larger box than if you recomputed the AABB of the original shape with the transform applied.