inv_mul_transforms

Function inv_mul_transforms 

pub fn inv_mul_transforms(a: Transform, b: Transform) -> Transform
Creates a transform that converts a local point in frame B to a local point in frame A. This is useful for transforming points between the local spaces of two frames that are in world space.