pub fn overlap_shape(
shape: &Shape,
transform: Transform,
proxy: &ShapeProxy,
) -> boolExpand description
Test overlap between a shape and a shape proxy. (b3OverlapShape)
pub fn overlap_shape(
shape: &Shape,
transform: Transform,
proxy: &ShapeProxy,
) -> boolTest overlap between a shape and a shape proxy. (b3OverlapShape)