shape_set_filter

Function shape_set_filter 

pub fn shape_set_filter(
    world: &mut World,
    shape_id: ShapeId,
    filter: Filter,
    invoke_contacts: bool,
)
(b3Shape_SetFilter)

When invoke_contacts is true, contacts on the shape are destroyed and the broad-phase proxy is refreshed so pairs are recomputed on the next step.