pub struct Counters {Show 20 fields
pub body_count: i32,
pub shape_count: i32,
pub contact_count: i32,
pub joint_count: i32,
pub island_count: i32,
pub stack_used: i32,
pub arena_capacity: i32,
pub static_tree_height: i32,
pub tree_height: i32,
pub sat_call_count: i32,
pub sat_cache_hit_count: i32,
pub byte_count: i32,
pub task_count: i32,
pub color_counts: [i32; 24],
pub manifold_counts: [i32; 8],
pub awake_contact_count: i32,
pub recycled_contact_count: i32,
pub distance_iterations: i32,
pub push_back_iterations: i32,
pub root_iterations: i32,
}Expand description
Counters that give details of the simulation size. (b3Counters)
byte_count, stack_used, arena_capacity, and task_count are always zero in this port: there is no global allocation tracker, no arena stack allocator, and no task system in the serial Rust implementation.
Fields
body_count: i32shape_count: i32contact_count: i32joint_count: i32island_count: i32stack_used: i32arena_capacity: i32static_tree_height: i32tree_height: i32sat_call_count: i32sat_cache_hit_count: i32byte_count: i32task_count: i32color_counts: [i32; 24]manifold_counts: [i32; 8]awake_contact_count: i32Number of contacts touched by the collide pass (graph contacts + awake-set non-touching).
recycled_contact_count: i32Number of contacts recycled in the most recent step.
distance_iterations: i32Maximum number of time of impact iterations
push_back_iterations: i32root_iterations: i32Trait Implementations
impl Copy for Counters
impl Eq for Counters
impl StructuralPartialEq for Counters