pub struct ExplosionDef {
pub mask_bits: u64,
pub position: Pos,
pub radius: f32,
pub falloff: f32,
pub impulse_per_area: f32,
}Expand description
The explosion definition is used to configure options for explosions. Explosions consider shape geometry when computing the impulse. (b3ExplosionDef)
Fields
mask_bits: u64Mask bits to filter shapes
position: PosThe center of the explosion in world space
radius: f32The radius of the explosion
falloff: f32The falloff distance beyond the radius. Impulse is reduced to zero at this distance.
impulse_per_area: f32Impulse per unit area. This applies an impulse according to the shape area that is facing the explosion. Explosions only apply to spheres, capsules, and hulls. This may be negative for implosions.