Structs
- Broad
Phase - The broad-phase is used for computing pairs and performing volume queries and ray casts. It does not persist pairs; it reports potentially new pairs. (b3BroadPhase)
Functions
- proxy_
id - (B3_PROXY_ID)
- proxy_
key - (B3_PROXY_KEY)
- proxy_
type - Store the proxy type in the lower 2 bits of the proxy key. (B3_PROXY_TYPE)
- update_
broad_ phase_ pairs - Find new proxy pairs and create contacts in deterministic move-array order. (b3UpdateBroadPhasePairs — serial)