Skip to main content Module core Copy item path Source HASH_INIT Initial value for hash . (base.h: B3_HASH_INIT) NULL_INDEX Used to indicate an unset or invalid index value. (base.h: B3_NULL_INDEX) SECRET_COOKIE Use to validate definitions. (core.h: B3_SECRET_COOKIE) bounding_power_of2 (ctz.h: b3BoundingPowerOf2) clz32 Count leading zeros of a 32-bit value. (ctz.h: b3CLZ32) ctz32 Count trailing zeros of a 32-bit block. (ctz.h: b3CTZ32) ctz64 Count trailing zeros of a 64-bit block. (ctz.h: b3CTZ64) get_length_units_per_meter Get the current length units per meter. get_stall_threshold Get the CCD stall threshold, in seconds. (core.c: b3GetStallThreshold) hash Hash data into hash (djb2-style, 8-byte little-endian words then bytes).
(timer.c: b3Hash) is_double_precision @return true if the library was built with the double-precision feature
(large world mode), mirroring BOX3D_DOUBLE_PRECISION. is_power_of2 (ctz.h: b3IsPowerOf2) lower_power_of_2_exponent Position of the most significant bit = floor(log2(x)). (ctz.h: b3LowerPowerOf2Exponent) non_zero_hash Geometry content hashes reserve zero to mean unhashed. (core.h: b3NonZeroHash) pop_count64 Population count of a 64-bit block. (ctz.h: b3PopCount64) round_up_power_of2 (ctz.h: b3RoundUpPowerOf2) set_length_units_per_meter Box3D bases all length units on meters. Set this to use different units for
all length values passed to and returned from Box3D. Must be set at
application startup, before any other Box3D calls. set_stall_threshold Set the CCD stall threshold, in seconds. (core.c: b3SetStallThreshold)