pub fn get_proxy_support(proxy: &ShapeProxy, axis: Vec3) -> i32Expand description
Support index for a shape proxy along an axis.
We move the first vertex into the origin for improved precision. This is necessary since we don’t have shape transforms and vertices can potentially be far away from the origin (large). (b3GetProxySupport)