pub fn mul_transforms(a: Transform, b: Transform) -> TransformExpand description
Multiply two transforms. If the result is applied to a point p local to frame B, the transform would first convert p to a point local to frame A, then into a point in the world frame. This is useful if frame B is a child of frame A.