Skip to main content Module solver_set Copy item path Source SolverSet Solver set data for contiguous storage of sims. AWAKE_SET Awake set for awake bodies with body states. (b3_awakeSet) DISABLED_SET Disabled set for disabled bodies and their joints. (b3_disabledSet) FIRST_SLEEPING_SET Index of the first sleeping set. (b3_firstSleepingSet) STATIC_SET Static set for static bodies and joints between static bodies. (b3_staticSet) destroy_solver_set (b3DestroySolverSet) merge_solver_sets This is called when joints are created between sets. I want to allow the sets
to continue sleeping if both are asleep. Otherwise one set is waked.
Islands will get merged when the set is woke. (b3MergeSolverSets) transfer_body Move a body sim between solver sets. (b3TransferBody) transfer_joint Move a joint sim between solver sets or the constraint graph. (b3TransferJoint) try_sleep_island Move a sleeping island (bodies, contacts, joints) from the awake set into a
new sleeping solver set. (b3TrySleepIsland) wake_solver_set Wake a solver set. Does not merge islands. (b3WakeSolverSet)